/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, ElementRef, EventEmitter, Renderer2, AfterViewChecked, SimpleChanges } from '@angular/core';
import { Orientation } from '../common/orientation';
import { SplitterService } from './splitter.service';
import * as i0 from "@angular/core";
/**
 * Represents the pane component of the Splitter.
 *
 * @example
 * ```html
 * <kendo-splitter>
 *   <kendo-splitter-pane size="30%" [collapsible]="true">
 *     Left pane content
 *   </kendo-splitter-pane>
 *   <kendo-splitter-pane>
 *     Right pane content
 *   </kendo-splitter-pane>
 * </kendo-splitter>
 * ```
 */
export declare class SplitterPaneComponent implements AfterViewChecked {
    element: ElementRef<HTMLElement>;
    private renderer;
    private cdr;
    private splitterService;
    /**
     * @hidden
     */
    set order(paneOrder: number);
    get order(): number;
    /**
     * Defines the initial size of the pane.
     * Accepts values in pixels and percentages.
     * The value must be between the `min` and `max` properties.
     */
    set size(newSize: string);
    get size(): string;
    /**
     * Defines the HTML attributes of the splitter bar.
     * Accepts string key-value pairs.
     * You cannot change attributes that are essential for certain functionalities.
     */
    set splitterBarAttributes(attributes: {
        [key: string]: string;
    });
    get splitterBarAttributes(): {
        [key: string]: string;
    };
    /**
     * Defines the CSS classes that are rendered on the splitter bar.
     * Supports the same values as [`ngClass`](link:site.data.urls.angular['ngclassapi']).
     */
    splitterBarClass: string | Array<string> | Object;
    /**
     * Defines the minimum possible size of the pane.
     * Accepts values in pixels and percentages.
     */
    min: string;
    /**
     * Defines the maximum possible size of the pane.
     * Accepts values in pixels and percentages.
     */
    max: string;
    /**
     * Determines if you can resize the pane and provide space for other panes.
     *
     * @default true
     */
    resizable: boolean;
    /**
     * Determines if you can hide the pane and provide space for other panes.
     *
     * @default false
     */
    collapsible: boolean;
    /**
     * Determines if overflowing content is scrollable or hidden.
     *
     * @default true
     */
    scrollable: boolean;
    /**
     * Determines if the pane is initially collapsed.
     *
     * @default false
     */
    collapsed: boolean;
    /**
     * @hidden
     */
    orientation: Orientation;
    /**
     * @hidden
     */
    set containsSplitter(value: boolean);
    /**
     * @hidden
     */
    overlayContent: boolean;
    /**
     * Fires when the Splitter pane size changes.
     * The event data contains the new pane size.
     * Enables two-way binding of the pane `size` property.
     */
    sizeChange: EventEmitter<string>;
    /**
     * Fires when the Splitter pane collapses or expands.
     * The event data contains the new property state.
     * Enables two-way binding of the `collapsed` pane property.
     */
    collapsedChange: EventEmitter<boolean>;
    get isHidden(): boolean;
    ariaRole: string;
    hostClass: boolean;
    get scrollablePaneClass(): boolean;
    get fixedSize(): boolean;
    /**
     * @hidden
     */
    forceExpand: boolean;
    /**
     * @hidden
     */
    isResized: boolean;
    private _size;
    private _order;
    private _splitterBarAttributes;
    constructor(element: ElementRef<HTMLElement>, renderer: Renderer2, cdr: ChangeDetectorRef, splitterService: SplitterService);
    ngAfterViewChecked(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * @hidden
     */
    get computedSize(): number;
    /**
     * @hidden
     */
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    toggleOverlay(show: boolean): void;
    /**
     * @hidden
     */
    detectChanges(): void;
    private setOrderStyles;
    private setStaticPaneClass;
    static ɵfac: i0.ɵɵFactoryDeclaration<SplitterPaneComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SplitterPaneComponent, "kendo-splitter-pane", ["kendoSplitterPane"], { "order": { "alias": "order"; "required": false; }; "size": { "alias": "size"; "required": false; }; "splitterBarAttributes": { "alias": "splitterBarAttributes"; "required": false; }; "splitterBarClass": { "alias": "splitterBarClass"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "resizable": { "alias": "resizable"; "required": false; }; "collapsible": { "alias": "collapsible"; "required": false; }; "scrollable": { "alias": "scrollable"; "required": false; }; "collapsed": { "alias": "collapsed"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; "containsSplitter": { "alias": "containsSplitter"; "required": false; }; "overlayContent": { "alias": "overlayContent"; "required": false; }; }, { "sizeChange": "sizeChange"; "collapsedChange": "collapsedChange"; }, never, ["*"], true, never>;
}
