/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy, EventEmitter, Renderer2, ElementRef, SimpleChanges, OnChanges } from '@angular/core';
import { StepperOrientation } from './models/orientation';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { StepType } from './models/step-type';
import { StepperStepTemplateDirective } from './template-directives/step-template.directive';
import { StepperLabelTemplateDirective } from './template-directives/label-template.directive';
import { StepperActivateEvent } from './events/activate-event';
import { StepperIndicatorTemplateDirective } from './template-directives/indicator-template.directive';
import { StepperService } from './stepper.service';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Stepper component for Angular]({% slug overview_stepper %}).
 *
 * @example
 * ```ts
 * @Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-stepper [steps]="steps">
 *     </kendo-stepper>
 *   `
 * })
 * class AppComponent {
 *   public steps: Array<StepperStep> = [
 *     { label: 'Step One' }, { label: 'Step Two' }, { label: 'Step Three' }
 *   ];
 * }
 * ```
 * @remarks
 * Supported children components are: {@link StepperCustomMessagesComponent}.
 */
export declare class StepperComponent implements OnChanges, OnDestroy {
    private renderer;
    private elem;
    private localization;
    private stepperService;
    hostClasses: boolean;
    get linearClass(): boolean;
    ariaRole: string;
    direction: string;
    displayStyle: string;
    /**
     * Specifies the type of the steps in the Stepper.
     *
     * @default 'indicator'
     */
    stepType: StepType;
    /**
     * Specifies the linear flow of the Stepper.
     *
     * @default true
     */
    linear: boolean;
    /**
     * Specifies the orientation of the Stepper
     * ([see example]({% slug orientation_stepper %})).
     *
     * @default 'horizontal'
     */
    orientation: StepperOrientation;
    /**
     * Specifies the index of the current step.
     */
    set currentStep(value: number);
    get currentStep(): number;
    /**
     * Specifies the collection of steps that will be rendered in the Stepper
     * ([see example]({% slug step_appearance_stepper %})).
     */
    set steps(steps: any[]);
    get steps(): any[];
    /**
     * Specifies an SVG icon to be rendered inside the step indicator instead of the default numeric or text content.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    set svgIcon(icon: SVGIcon);
    get svgIcon(): SVGIcon;
    /**
     * Specifies an SVG icon to be rendered for the success icon.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    successSVGIcon: SVGIcon;
    /**
     * Specifies an SVG icon to be rendered for the error icon.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    errorSVGIcon: SVGIcon;
    /**
     * Specifies an SVG icon that will be rendered inside the step for valid previous steps.
     * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
     */
    successIcon: string;
    /**
    * Specifies an SVG icon that will be rendered inside the step for invalid previous steps.
    * You can use either an [existing Kendo SVG icon](slug:svgicon_list) or a custom one.
    */
    errorIcon: string;
    /**
     * Specifies the duration of the progress indicator animation in milliseconds.
     *
     * @default true
     */
    animation?: boolean | number;
    /**
     * Fires when a step is about to be activated. You can prevent this event.
     */
    activate: EventEmitter<StepperActivateEvent>;
    /**
     * Fires when the `currentStep` property of the component was updated.
     * Use this event to provide a two-way binding for the `currentStep` property.
     */
    currentStepChange: EventEmitter<number>;
    /**
     * @hidden
     */
    stepTemplate: StepperStepTemplateDirective;
    /**
     * @hidden
     */
    labelTemplate: StepperLabelTemplateDirective;
    /**
     * @hidden
     */
    indicatorTemplate: StepperIndicatorTemplateDirective;
    private dynamicRTLSubscription;
    private _steps;
    private _successSVGIcon;
    private _errorSVGIcon;
    private _svgIcon;
    constructor(renderer: Renderer2, elem: ElementRef, localization: LocalizationService, stepperService: StepperService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /**
     * Manually triggers the validity check configured by the [isValid]({% slug api_layout_stepperstep %}#toc-isvalid) property of the steps ([see example]({% slug step_validation_stepper %}#toc-triggering-the-validation)).
     *
     * Steps that have their [validate]({% slug api_layout_stepperstep %}#toc-validate) property set to `false`, will not be validated.
     */
    validateSteps(): void;
    private applyHostStyling;
    private resetHostStyling;
    /**
     * @hidden
     */
    get progressAnimation(): any;
    /**
     * @hidden
     */
    get animationDuration(): number;
    /**
     * @hidden
     */
    get stepsListStyling(): Object;
    /**
     * @hidden
     */
    get progressBarStyling(): Object;
    /**
     * @hidden
     */
    onListKeydown(e: any): void;
    /**
     * @hidden
     */
    onListClick(e: any): void;
    /**
     * @hidden
     */
    get isHorizontal(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<StepperComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<StepperComponent, "kendo-stepper", ["kendoStepper"], { "stepType": { "alias": "stepType"; "required": false; }; "linear": { "alias": "linear"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; "currentStep": { "alias": "currentStep"; "required": false; }; "steps": { "alias": "steps"; "required": false; }; "svgIcon": { "alias": "svgIcon"; "required": false; }; "successSVGIcon": { "alias": "successSVGIcon"; "required": false; }; "errorSVGIcon": { "alias": "errorSVGIcon"; "required": false; }; "successIcon": { "alias": "successIcon"; "required": false; }; "errorIcon": { "alias": "errorIcon"; "required": false; }; "animation": { "alias": "animation"; "required": false; }; }, { "activate": "activate"; "currentStepChange": "currentStepChange"; }, ["stepTemplate", "labelTemplate", "indicatorTemplate"], never, true, never>;
}
